@@ -7,14 +7,12 @@
  * the terms of the GNU Library General Public License version 2.
  */
 
- /*
-  * TODO:
-  * - Documentation:
-  * - Look through the api and implement the last 2 methods.
-  */
-
+/**
+ * Represents a rectangle with x, y, width and height members.
+ */
 package org.gnu.gdk;
 import org.gnu.glib.Boxed;
+import org.gnu.glib.GObject;
 import org.gnu.glib.Handle;
 public class Rectangle extends Boxed 
 {
@@ -23,51 +21,98 @@ public class Rectangle extends Boxed
 		this.handle=handle;
 	}
 	
+    /**
+     * Retrieve the x coordinate for the Rectangle.
+     */
 	public int getX(){
 		return Rectangle.getX(handle);
 	}
 	
+    /**
+     * Set the x coordinate for the Rectangle.
+     * @param x
+     */
 	public void setX(int x){
 		setX(handle,x);		
 	}
 	
+    /**
+     * Retrieve the y coordinate for the Rectangle.
+     */
 	public int getY(){
 		return Rectangle.getY(handle);
 	}
 	
+    /**
+     * Set the y coordinate for the Rectangle.
+     * @param y
+     */
 	public void setY(int y){
 		setY(handle,y);
 	}
 	
+    /**
+     * Retrieve the width of the Rectangle.
+     */
 	public int getWidth(){
 		return Rectangle.getWidth(handle);
 	}
 	
+    /**
+     * Set the width of the Rectangle.
+     * @param width
+     */
 	public void setWidth(int width){
 		setWidth(handle,width);
 	}
 	
+    /**
+     * Retrieve the height of the Rectangle.
+     */
 	public int getHeight(){
 		return Rectangle.getHeight(handle);
 	}
 	
+    /**
+     * Set the height of the Rectangle.
+     * @param heigth
+     */
 	public void setHeight(int heigth){
 		setHeight(handle,heigth);
 	}
 	
-	// Not sure if it must be its behaviour.
-	// Incomplete.
-	public Rectangle intersect(Rectangle src1,Rectangle src2){
-		//Rectangle.gdk_rectangle_intersect(src1.getHandle(),src2.getHandle(),
+	/**
+     * Returns the intersection of this Rectangle and the provided Rectangle or
+     * null if there is no intersection. 
+     * @param rect
+	 */
+	public Rectangle intersect(Rectangle rect){
+        Handle intersect = GObject.getNullHandle();
+		boolean val = gdk_rectangle_intersect(getHandle(), rect.getHandle(), intersect);
+        if (val)
+            return new Rectangle(intersect);
 		return null;
 	}
 	
-	// The same as the previous.
-	//	must look api.
-	public Rectangle union(Rectangle src1,Rectangle src2){
-		return null;
+	/**
+     * Returns the union of this Rectangle and the provided Rectangle or
+     * null if there is no union.
+     * @param rect
+	 */
+	public Rectangle union(Rectangle rect){
+        Handle union = GObject.getNullHandle();
+        gdk_rectangle_union(getHandle(), rect.getHandle(), union);
+		if (union.isNull())
+            return null;
+        return new Rectangle(union);
 	}
-		
+	
+    protected void finalize() throws Throwable {
+        super.finalize();
+        free(getHandle());
+    }
+    
+    
     native static final protected int getX (Handle obj);
     native final protected void setX (Handle obj, int x);
     native static final protected int getY (Handle obj);
@@ -78,5 +123,6 @@ public class Rectangle extends Boxed
     native final protected void setHeight (Handle obj, int height);
     native static final protected boolean gdk_rectangle_intersect (Handle src1, Handle src2, Handle dest);
     native static final protected void gdk_rectangle_union (Handle src1, Handle src2, Handle dest);
+    native static final protected void free(Handle obj);
 }
 
