@@ -45,5 +45,12 @@ public class VButtonBox extends ButtonBox
 
     native static final protected int gtk_vbutton_box_get_type ();
     native static final protected Handle gtk_vbutton_box_new ();
+
+    /*
+    native static final private int gtk_vbutton_box_get_spacing_default();
+    native static final private void gtk_vbutton_box_set_spacing_default(int spacing);
+    native static final private int gtk_vbutton_box_get_layout_default();
+    native static final private void gtk_vbutton_box_set_layout_default(int layout);
+    */
 }
 
